<?php include('header.php'); ?>
<center>
<H2>MaCH-Admix beta Tutorial</H2>
</center>
<div align=left>
<pre>
MaCH-Admix is an extension to <a href="http://www.sph.umich.edu/csg/yli/mach">MaCH</a> for faster and more flexible imputaiton, especially in admixed populations. 
All existing MaCH documentation applies to MaCH-Admix. For general input file preparation and haplotyping 
options, please see: <a href="https://www.sph.umich.edu/csg/yli/mach/tour/">MaCH tutorial</a>

Basically, in order to run MaCH-Admix, you need to go through the following steps:
<ul><li> <a href="#input">Prepare input files</a> 
<li> <a href="#runmode">Pick a run-mode</a>
<li> <a href="#selectmode">(optional) Pick a reference selection mode</a>
<li> <a href="#otheroptions">(optional) Explore other options</a>
<li> <a href="#output">Interpret output files</a>
</ul>
Other issues included in this page:
<ul><li> <a href="#estimateancestry">Estimate Ancestry-Weights of Reference Populations</a>
<li> <a href="#1000genome">Imputation with 1000 Genomes Data</a>
<li> More to be added...</ul>
<a name="input"></a>
<b><font size=4>Preparing Input Files</font></b>
A typical imputation scenario invovles:
<ul><li> a ped file containing all observed genotypes of target individuals (typically in <a href="http://www.sph.umich.edu/csg/yli/mach/tour/input_files.html" target=_blank>MERLIN/QTDT format</a>)
<li> a dat file containing all markers present in the above ped file (typically in <a href="http://www.sph.umich.edu/csg/yli/mach/tour/input_files.html" target=_blank>MERLIN/QTDT format</a>)
<li> a haps file containing all reference phased haplotypes (e.g., Hapmap2 or 3 phased haplotype files, or phased 1000-Genome hap files) 
<li> a snps file containing all markers present in the above hap file (e.g., the snps files come with Hapmap2 or 3 phased haplotype files) 
</ul>
The four input files are specified using the following command line options:
<ul><li> ped file: -p or --pedfile &lt;filename&gt;
<li> dat file: -d or --datfile &lt;filename&gt;
<li> haps file: -h or --haps &lt;filename&gt;
<li> snps file: -s --snps &lt;filename&gt;
</ul>
Example:<br>
<span class=code><font color="#3333CC">-d target.dat -p target.ped -h ref.hap -s ref.snps</font></span><br>
For more information on input genotype and dat(marker list) file, please see <a href="http://www.sph.umich.edu/csg/yli/mach/tour/input_files.html" target=_blank>here</a> and <a href="http://www.sph.umich.edu/csg/yli/mach/tour/" target=_blank>here</a>.
For more information on HapMap2/3 haps and snps files, please <a href="http://www.sph.umich.edu/csg/yli/mach/download/HapMap-r21.html" target=_blank>HapMapII r21</a>, <a href="http://www.sph.umich.edu/csg/yli/mach/download/HapMap-r22.html" target=_blank>HapMapII r22</a>, <a href="http://www.sph.umich.edu/csg/yli/mach/download/HapMap3.r2.b36.html" target=_blank>HapMapIII r2</a>.
For more information on 1000-Genome haps and snps files, please see <a href="http://www.sph.umich.edu/csg/yli/mach/download/1000G-PhaseI-Interim.html" target=_blank>1000G 201101123</a>.

A reminder: Before genotype imputation, you should carry out basic data quality checks on available genotypes. Typically, we exclude 
from analysis markers that have low genotyping success rates (perhaps with &lt;95% of genotypes called successfully), unexpected evidence 
for deviations from Hardy-Weinberg equilibrium (perhaps with an HWE p-value < 1e-6 or so), large numbers of discrepancies among 
duplicate samples or with several mendelian inconsistensies in available parent-offspring trios, or that are rare (with MAF &lt; 1% or so). 
All these checks are platform and study specific, and you'll have to figure out what is appropriate for your data. 


<a name="runmode"></a>
<b><font size=4>Run Mode Choices</font></b>
There are two ways to conduct imputation:
<ul><li> <B>Integrated</B>: using this mode, the user doesn't need to specify any model parameters.
Model parameters include recombination rates and error rates that will be stored in .rec and .erate files respectively. 
MaCH-Admix will integrate both parameter estimation and imputation in MCMC iterations. This mode is suitable 
when model parameters are either not available or calibrated using a population poorly matched to 
the target/to-be-imputed population. To use the integrated mode:
	<ul><li> specify all four input files (ped/dat/haps/snps)<li> use command line option "<font color="#CC0000">--runMode Integrated</font>"
	Example: 
<span class=code>	./mach-admix <font color="#009900">--geno</font> <font color="#CC0000">--runMode Integrated</font> <font color="#3333CC">-d target.dat -p target.ped -h ref.hap -s ref.snps</font></span>
	Noe that the "<font color="#009900">--geno</font>" option here requests for the best-guessed genotypes (after imputation).</ul>
<li> <B>2-step</B>: using this mode, the user first calibrate all model parameters (recombination rate / error rate). 
Then MaCH-Admix can use the calibrated parameters to conduct imputation without parameter learning. This 2-step model 
is suitable if the user repeatedly use the same set of data (e.g. the same reference haps/snps files), or has obtained
parameter files beforehand. With pre-calibrated parameters, the 2nd step alone is faster than the <B>Integrated</B> mode.
	<ul><li> Step-1: calibrate parameters using command line option "<font color="#CC0000">--runMode EstimateParameterOnly</font>"
	Example:
<span class=code>	./mach-admix <font color="#CC0000">--runMode EstimateParameterOnly</font> <font color="#009900">--prefix parameters</font> <font color="#3333CC">-d target.dat -p target.ped -h ref.hap -s ref.snps</font></span>
	The "<font color="#009900">--prefix</font>" option specifies the output filename.
		<li> Step-2: conduct imputation using calibrated parameter file and command line option "<font color="#CC0000">--runMode ImputeOnly</font>"
	Example:
<span class=code>	./mach-admix --geno <font color="#CC0000">--runMode ImputeOnly</font> <font color="#009900">--crossoverMap parameters.rec --errorMap parameters.erate</font> \
	<font color="#3333CC">-d target.dat -p target.ped -h ref.hap -s ref.snps</font></span>
	Note the two parameter files specified ("<font color="#009900">--crossoverMap parameters.rec --errorMap parameters.erate</font>").
</ul></ul>

<a name="selectmode"></a>
<b><font size=4>(Optional) Pick a reference selection mode</font></b>
MaCH-Admix uses hidden Markov model (HMM) to infer unobserved genotypes. In such a
model, the computational cost grows quadratically with the number of reference haplotypes used. To accelerate
computation, MaCH-Admix utilizes approximation by sampling a small proportion from the available reference haplotypes
in each round as the effective reference panel. By default, MaCH-Admix uses random sampling which 
is a safe choice in all situations. In addition, MaCH-Admix has the following two approaches that 
can further improve imputation accuracy depending on users' specific tasks:

<ul><li><b><font size=2>IBS-based Sampling</font></b>
The IBS-based approaches will construct a tailored reference panel for each individual depending on 
the person's genetic background. Specifically, the IBS-based approaches achieve this by comparing the 
genetic similarity (measured by IBS) between the target individual and every haplotype in the reference pool.

<b><font color="#CC0000">IBS-based sampling is generally good for imputation in short region (<10Mb), for both admixed and non-admixed populations.</font></b>

In MaCH-Admix, we provide the following IBS options:
<ul><li><b><font size=2> IBS Double-Queue</font></b>
This is the default recommended strategy in most situations. In this approach, we sort all reference
haplotypes according to their similarity to the two guessed haplotypes of each target individual. We
maintain two separate priority queues, one for each of the guessed haplotypes. 
To switch to this Double-Queue selection approach, use "<font color="#CC0000">--selectMode IBSDQ</font>" command line option.

Example
<span class=code>./mach-admix --geno --runMode Integrated <font color="#CC0000">--selectMode IBSDQ</font> <font color="#3333CC">-d target.dat -p target.ped -h ref.hap -s ref.snps</font></span>

<li><b><font size=2>Allele frequency weighted Double-Queue</font></b>
This approach is similar to the Double-Queue approach above. The major difference is that, instead 
of computing a Hamming distance where each site carries the same weight, this approach gives 
higher weight to sites with lower minor allele frequency. To switch to this approach, use
"<font color="#CC0000">--selectMode IBSWeighted</font>" command line option.

Example Usage:
<span class=code>./mach-admix --geno --runMode Integrated <font color="#CC0000">--selectMode IBSWeighted</font> <font color="#3333CC">-d target.dat -p target.ped -h ref.hap -s ref.snps</font></span>

<li><b><font size=2>Single-Queue</font></b>
This is the basic IBS-based approach that maintains only one priority queue for each target 
individual. This approach is generally worse than the double-queue approach. 
To switch to this approach, use use "<font color="#CC0000">--selectMode IBSSQ</font>" command line option.</ul>

<li><b><font size=2>Ancestry-Weighted Sampling</font></b>
This approach concerns the scenario in which the reference panel consists of haplotypes from several 
reference populations, for instance CEU and YRI for African Americans. The user can specify beforehand
the desired weight (expected ancestral contribution) of each reference population. This is done by providing
an ancestry-weight file to MaCH-admix. Each line in the weight file corresponds to one reference
population and has two numbers, the population size (number of individuals, or 2*haplotypes) and the expected 
weight of <b>each reference population</b>. An example of the ancestry-weight file is shown below:

[File: AncestryWeights.cfg]
	60 0.2
	60 0.8

The example specifies two reference populations, each with 60 individuals (120 haplotypes). The reference
haplotype file must have consistent content (i.e. 60*2 haplotypes from the first population followed
by 60*2 haplotypes from the second population ) After specifying the ancestry-weight file and ancestry-
weighted sampling mode, each individual in the first(second) population will carry a weight of 0.2(0.8) 
in MCMC iterations. Note that the weights can be in arbitrary scale (MaCH-Admix does internal normalization). 

Example Usage:
<span class=code>	./mach-admix --geno --runMode Integrated <font color="#009900">--ancweightfile AncestryWeight.cfg</font>  <font color="#CC0000">--selectMode AncestryWeighted</font> \
	<font color="#3333CC">-d target.dat -p target.ped -h ref.hap -s ref.snps</font></span>

Here, "<font color="#CC0000">--selectMode AncestryWeighted</font>" specifies the Ancestry-Weighted selection option
	"<font color="#009900">--ancweightfile AncestryWeight.cfg</font>" specifies the name of the ancestry-weight file. Note that the 
	        total number of individuals in this file must agree with that in the reference haplotype file.

	<b>Determining the weights</b>
	A key question here is how to determine the weights. There are several natural ways to estimate the 
	weights. One could pre-specify the weights according to estimates for ancestry proportion, for example, 
	African Americans have about 20% Caucasian and 80% African ancestries, therefore, it is reasonable to 
	use ~2:8 ratio of CEU:YRI in weighting.
	
	Alternatively, the user can use the built-in feature provided by MaCH-Admix to infer ancestry proportions (please see <a href="#estimateancestry">here</a>). 
        User can also use other software such as STRUCTURE and HAPMIX.
</ul>

<a name="otheroptions"></a>
<b><font size=4>(Optional) Explore Other Available options</font></b>
There are many other useful options:
<ul><li><font color="#660000"><b>--geno</b></font>: Output best-guess genotypes.
<li><font color="#660000"><b>--dosage</b></font>: Output allele dosages (estimated number of copies of Al1 at each SNP for each individual, ranging continuously from 0 to 2).
<li><font color="#660000"><b>--autoflip</b></font>: Automatically flip strand if the alleles in target(ped) and reference(haps) files are inconsistent
<li><font color="#660000"><b>--errorRate</b></font>: Specify the base error rate. The default value is 0.001.
		Normally the user does not need to set this because MaCH-Admix will adjust this value in each iteration.
		Set this to a higher/lower value if your data are very noisy/clean to help accelerate the adjustment.
<li><font color="#660000"><b>--probs</b></font>: Output posterior probabilities (two probabilities, for Al1/Al1 and Al1/Al2 respectively, for each genotype guessed).
<li><font color="#660000"><b>--qc</b></font>: Output quality score for each genotype guessed.
<li><font color="#660000"><b>--phase</b></font>: Perform phasing and output best-guess haplotypes.
		If you plan to perform phasing, we recommend a larger --states value (>200).
		The default value is good for imputation but may be insufficient for phasing.
<li><font color="#660000"><b>--rounds &lt#rounds&gt;</b></font>: Specify the number of MCMC rounds. Default value is 30 which is good enough 
		for standard imputation tasks. Computing time grows linearly #rounds. 
		More rounds is better at increased computational costs. 
<li><font color="#660000"><b>--states &lt#states&gt;</b></font>: Specify the number of reference haplotypes sampled in interal phasing step. The default value is 100.
		Computing time grows quadratically with #states. 
		Larger states is better at increased computational costs.
<li><font color="#660000"><b>--referencesInFitting &lt#referencesInFitting&gt;</b></font>: Specify the number of reference haplotypes used in parameter learning.
		The default value is 500. Computing time is affected only minimally by #referencesInFitting.
<li><font color="#660000"><b>--imputeStates &lt#imputeStates&gt;</b></font>: Specify the number of reference haplotypes used in internal imputing step. The default value is 500.
		Computing time is affected only minimally by #imputeStates.
<li><font color="#660000"><b>--seed &lt#seed&gt;</b></font>: Specify random seed.
<li><font color="#660000"><b>--interimInterval &lt#interimRounds&gt;</b></font>: Output intermediate results every #interimRounds rounds.
		The option is useful when computing time is very long for running all #rounds.
<li><font color="#660000"><b>--prefix &lt;fileprefix&gt;</b></font>: Specify the prefix for all output files
<li><font color="#660000"><b>--uncompressed</b></font>: Choose not to compress output files. By default all
		output files are written out in .gz format (if compiled with gzip support).
<li><font color="#660000"><b>--mask &lt;proportion&gt;</b></font>: Randomly mask a small proportion of input genotypes to evaluate imputation quality.</ul>

<a name="output"></a>
<b><font size=4>Interpret output files</font></b>
Most output files are self-explanatory. Details will be added to this section.
<ul><li>.geno / .geno.gz: Best guessed genotypes generated using --geno option
<li>.dose / .dose.gz: Genotypes dosage file generated using --dosage option
<li>.prob / .prob.gz: Genotypes probability file generated using --probs option
<li>.qc / .qc.gz: Quality control information file generated using --quality option
<li>.rec and .erate: measured recombination and error rate parameter file. always generated.
</ul>

<a name="estimateancestry"></a>
<b><font size=4>Estimate Ancestry-Weights of Reference Populations</font></b>
MaCH-admix has a built-in feature to estimate the contributions of reference populations. To use this feature, 
the user has to provide ancestry-weight file with arbitrarily defined weights. MaCH-admix reads the reference 
population structure from this file. An example is shown below:

[File: AncestryWeights.cfg]
	60 1.0
	60 1.0

The example specifies two reference populations, each with 60 individuals (120 haplotypes). The reference
haplotype file must have consistent structure (i.e. 60*2 haplotypes from the first population followed
by 60*2 haplotypes from the second population ) We put arbitrary weights (1.0) here. The user can combine
any non-ancestry-weighted reference selection with "--ancweightfile" option to obtain an estimate of population
contributions. However, for short regions, we recommend the double-queue IBS approach ("--selectMode IBSDQ") 
for it is more reliable with small number of states/rounds.

Example:
<span class=code>./mach-admix --runMode Integrated <font color="#CC0000">--selectMode IBSDQ  --ancweightfile AncestryWeight.cfg</font> \
	<font color="#3333CC">-d target.dat -p target.ped -h ref.hap -s ref.snps</font></span>

Example Output:
<span class=code>	============== BEGIN: Contribution of Reference Populations ==============
	 Reference Population 1: 0.221873					
	 Reference Population 2: 0.778127					
	============== END: Contribution of Reference Populations ==============</span>

<a name="1000genome"></a>
<b><font size=4>Imputation with 1000 Genomes Data</font></b>

To be added....
<!-- <ul><li><b>Your Own Data</b>
To get started, you will need to store your data in Merlin format pedigree and data files, one per chromosome. 
See the beginning of this page.

<li><b>Reference Haplotypes</b>
Reference haplotypes generated by the 1000 Genomes project and formatted so that they are ready for analysis are 
available from the MaCH download page. The most recent set of haplotypes is usually available from the MaCH 
download page. Improvements in genotype calling and haplotyping methods, together with generation of progressively 
larger amounts of sequence data mean that, typically, it is better to use the most recent set of 1000 Genomes 
Project Haplotypes.  -->

</pre>
</div>
<p>Comments and suggestions are <span class=GramE>welcome,</span> please e-mail
<a href="http://www.sph.umich.edu/csg/yli/index.html">Yun Li</a> at <a href="mailto:yunpersonal@gmail.com">yunli@med.unc.edu</a>
or <a href="http://liuyi1.com">Eric Yi Liu</a> at
<a href="mailto:liuyi@cs.unc.edu">liuyi@cs.unc.edu</a>.<o:p></o:p></p>

<?php include('footer.php'); ?>
